@@ -1,7 +1,7 @@
 points.segmented <-function(x, term, interc=TRUE, link=TRUE, 
     rev.sgn=FALSE, transf=I, .vcov=NULL, .coef=NULL, const=0, v=TRUE, ...){
 #--------------
-        f.U<-function(nomiU, term=NULL){
+      f.U<-function(nomiU, term=NULL){
         #trasforma i nomi dei coeff U (o V) nei nomi delle variabili corrispondenti
         #and if 'term' is provided (i.e. it differs from NULL) the index of nomiU matching term are returned
             k<-length(nomiU)
@@ -17,9 +17,15 @@ points.segmented <-function(x, term, interc=TRUE, link=TRUE,
         }
 #-------------
       if(missing(term)){
-          if(length(x$nameUV$Z)>1 ) {stop("please, specify `term'")}
-               else {term<-x$nameUV$Z}
-               }
+        if(length(x$nameUV$Z)>1 ){
+          stop("please, specify `term'")
+          } else {
+            term<-x$nameUV$Z
+          }
+        } else {
+          term<- if(is.numeric(term)) x$nameUV$Z[term] else term
+        }
+      if(!term%in%x$nameUV$Z) stop("unknown 'term' ")
       opz<-list(...)
       if(is.null(opz$col)) opz$col <- 2
       if(is.null(opz$lty)) opz$lty <- 3
@@ -27,13 +33,17 @@ points.segmented <-function(x, term, interc=TRUE, link=TRUE,
       psii<- x$psi[nameV, "Est."]
       d<-data.frame(a=psii)
       names(d)<-term
-      opz$y<-broken.line(x,d, se.fit=FALSE, interc=interc, link=link, .coef=.coef, .vcov=.vcov)[[1]]
+      opz$y<-broken.line(x,d, se.fit=FALSE, interc=interc, link=TRUE, .coef=.coef, .vcov=.vcov)[[1]]
       #browser()
       if(rev.sgn) psii<- -psii
       opz$x<- psii 
       if(is.null(opz$cex)) opz$cex<-1.25
       if(is.null(opz$lwd)) opz$lwd<-1.6
       opz$y <- opz$y + const
+      #browser()
+      if(inherits(x, "glm") && !link) {
+        opz$y<- x$family$linkinv(opz$y)
+      }
       opz$y<-do.call(transf, list(opz$y))
       do.call(points, opz)
       if(v) segments(psii, par()$usr[3], psii, opz$y, lty = opz$lty, col=opz$col )
