@@ -1,15 +1,15 @@
 step.ts.fit<-function(y, x.lin, Xtrue, PSI, opz, return.all.sol=FALSE){  
   #----------------------
-  search.min<-function(h, psi, psi.old, X, y) {
+  search.min<-function(h, psi, psi.old, X, y, id.fix.psi=NULL) {
     psi.ok<- psi*h + psi.old*(1-h)
-    PSI <- matrix(rep(psi.ok, rep(n, length(psi.ok))), ncol = length(psi.ok))
+    psi.ok[id.fix.psi]<- psi.old[id.fix.psi]
+    PSI <- matrix(psi.ok, n, ncol = length(psi.ok), byrow=TRUE)
     U1 <- (Xtrue>PSI) #(Z - PSI) * (Z > PSI)
     #if (pow[1] != 1) U1 <- U1^pow[1]
     obj1 <- try(mylm(cbind(X, U1), y), silent = TRUE)
     #if (class(obj1)[1] == "try-error") obj1 <- try(lm.wfit(cbind(X, U1), y, w, offs), silent = TRUE)
-    if (class(obj1)[1] == "try-error") obj1 <- try(.lm.fit(cbind(X, U1), y), silent = TRUE)
-    L1 <- if (class(obj1)[1] == "try-error") L0 + 10
-    else sum(obj1$residuals^2)
+    #if (class(obj1)[1] == "try-error") obj1 <- try(.lm.fit(cbind(X, U1), y), silent = TRUE)
+    L1 <- if (class(obj1)[1] == "try-error") L0 + 10 else obj1$L0
     #r<-sum(obj1$residuals^2 * w)
     L1
   }
@@ -34,11 +34,14 @@ step.ts.fit<-function(y, x.lin, Xtrue, PSI, opz, return.all.sol=FALSE){
     #b<-solve(crossprod(x),crossprod(x,y))
     #browser()
     #fit<- drop(tcrossprod(x,t(b)))
-    fit<- drop(tcrossprod(b,x))
+    fit<- drop(x%*%b)
     r<-y-fit
-    o<-list(coefficients=b,fitted.values=fit,residuals=r, df.residual=length(y)-length(b))
+    o<-list(coefficients=b, fitted.values=fit, residuals=r, L0=sum(r^2), df.residual=length(y)-length(b))
     o
   }
+  ### -----
+  isZero <- function(v) sapply(v, function(.x) identical(.x,0))
+  ###------
   #-----------
   adj.psi <- function(psii, LIM) {
     pmin(pmax(LIM[1, ], psii), LIM[2, ])
@@ -49,9 +52,9 @@ step.ts.fit<-function(y, x.lin, Xtrue, PSI, opz, return.all.sol=FALSE){
   display<-opz$display
   it.max<-opz$it.max
   dev0<-opz$dev0
-  useExp.k<-opz$useExp.k
-  min.step<- opz$min.step #=.0001
-  conv.psi<-opz$conv.psi #=FALSE
+  #useExp.k<-opz$useExp.k
+  #min.step<- opz$min.step #=.0001
+  #conv.psi<-opz$conv.psi #=FALSE
   alpha<-opz$alpha
   #browser()
   limZ <- apply(Xtrue, 2, quantile, names = FALSE, probs = c(alpha[1], alpha[2]))
@@ -72,6 +75,7 @@ step.ts.fit<-function(y, x.lin, Xtrue, PSI, opz, return.all.sol=FALSE){
   pos<- tapply(1:npsi, rep(1:P, npsii), list)
   i <- 0
   agg <- rep(agg, npsi)
+  #browser()
   #  direz <- matrix(NA, it.max, npsi)
   #  conv <- rep(FALSE, npsi)
   #  ind.conv <- NULL
@@ -80,16 +84,30 @@ step.ts.fit<-function(y, x.lin, Xtrue, PSI, opz, return.all.sol=FALSE){
   epsilon<-10
   k.values<-dev.values<- NULL
   psi.values <-list()
+  
+  dev.values[length(dev.values) + 1] <- opz$dev0 #modello senza psi 
   psi.values[[length(psi.values) + 1]] <- NA
   #PSI0<- matrix(psi0, n, npsi, byrow = TRUE)
   #XREG <- cbind(x.lin, Xtrue>PSI)
   #obj0 <- .lm.fit(x=XREG, y=y) #try(mylm(XREG, y), silent = TRUE) 
   #L0 <- sum(obj0$residuals^2) #*ww
   
-  L0<- dev0*.8
+  if(it.max==0){
+    obj <- lm.wfit(x = cbind(x.lin, Xtrue>PSI), y = y)
+    L1 <- sum(obj$residuals^2)
+    obj$epsilon <- epsilon
+    idZ<-(plin+1):(plin+ncol(PSI))
+    b<- obj$coef[idZ]
+    obj <- list(obj = obj, psi = PSI[1,], psi.values = psi.values, 
+                rangeZ = rangeZ, beta.c=b, epsilon = epsilon,  
+                SumSquares.no.gap = L1,  
+                id.warn = TRUE)
+    return(obj)
+  }
+  
+  L0<- mylm(cbind(x.lin, Xtrue>PSI),y)$L0 # valore con psi iniziale
   
   n.intDev0<-nchar(strsplit(as.character(L0),"\\.")[[1]][1])
-  dev.values[length(dev.values) + 1] <- dev0#opz$dev0 #del modello iniziale (senza psi)
   dev.values[length(dev.values) + 1] <- L0 #modello con psi iniziali
   psi0<-PSI[1,]
   psi.values[[length(psi.values) + 1]] <- psi0 #psi iniziali
@@ -109,7 +127,11 @@ step.ts.fit<-function(y, x.lin, Xtrue, PSI, opz, return.all.sol=FALSE){
   low <- apply(Xtrue, 2, min)
   up <- apply(Xtrue, 2, max)
   
-  L1<-L0+10  
+  #L1<-L0+10  
+  tolOp<-if(is.null(opz$tol.opt)) seq(.001, .Machine$double.eps^0.25, l=it.max) else rep(opz$tol.opt, it.max)
+  idZ<-(plin+1):(plin+ncol(PSI))
+  idW<-(plin+ncol(PSI)+1): ( plin+2*ncol(PSI))
+  
   #==============================================
   while (abs(epsilon) > tol) {
     i <- i + 1
@@ -118,6 +140,7 @@ step.ts.fit<-function(y, x.lin, Xtrue, PSI, opz, return.all.sol=FALSE){
     for (p in 1:P) {
       psis <- sort(psi0[pos[[p]]])
       gruppi <- cut(xx[,p], breaks = c(low[p] - 0.1, psis, up[p]), labels = FALSE)
+      if(any(is.na(gruppi))) stop(paste("too many breaks for step term #", p, "?"), call.=TRUE)
       points <- c(low[p], psis, up[p])
       right <- c(low[p], points[2:(npsii[p] + 1)] + agg[pos[[p]]][order(psi0[pos[[p]]])] * (points[3:(npsii[p] + 2)] - points[2:(npsii[p] + 1)]), NA)
       left <- c(NA, points[2:(npsii[p] + 1)] - agg[pos[[p]]][order(psi0[pos[[p]]])] * (points[2:(npsii[p] + 1)] - points[1:npsii[p]]), up[p])
@@ -140,34 +163,62 @@ step.ts.fit<-function(y, x.lin, Xtrue, PSI, opz, return.all.sol=FALSE){
     #b <- obj$coef[(2:(sum(k) + 1))]
     #g <- obj$coef[((sum(k) + 2):(2 * sum(k) + 1))]
     
-    idZ<-(plin+1):(plin+ncol(Z))
-    idW<-(plin+ncol(Z)+1): ( plin+ncol(Z)+ncol(W))
     b<- obj$coef[idZ]
     g<- obj$coef[idW]
     
-    if(any(is.na(c(b, g)))){
+    #if(any(is.na(c(b, g)))){
+    if(any(isZero(c(b, g)))) {
       if(return.all.sol) return(list(dev.values, psi.values)) else stop("breakpoint estimate too close or at the boundary causing NA estimates.. too many breakpoints being estimated?", call.=FALSE)
     }
     psi1 <- -g/b
-    #aggiusta la stima di psi..
+    psi1<- psi0+ h*(psi1-psi0)
     psi1<- adj.psi(psi1, limZ) #limZ rangeZ
-    
+    psi1<-unlist(tapply(psi1, opz$id.psi.group, sort), use.names =FALSE)
     #la f e' chiaramente a gradino per cui meglio dividere..
-    a0<-optimize(search.min, c(0,.5), psi=psi1, psi.old=psi0, X=x.lin, y=y)
-    a1<-optimize(search.min, c(.5,1), psi=psi1, psi.old=psi0, X=x.lin, y=y)
+    a0<-optimize(search.min, c(0,.5), psi=psi1, psi.old=psi0, X=x.lin, y=y, tol=tolOp[i])
+    a1<-optimize(search.min, c(.5,1), psi=psi1, psi.old=psi0, X=x.lin, y=y, tol=tolOp[i])
     a<-if(a0$objective<=a1$objective) a0 else a1
     
-    #M<-1
-    #while(L1>L0){
-    #  a<-optimize(search.min, c(0,M), psi=psi1, psi.old=psi0, X=x.lin, y=y, w=ww, offs=offs)
-    #  L1<- a$objective
-    #  M<-M*.3
-    #}
-    k.values[length(k.values) + 1] <- use.k <- a$minimum
-    L1<- a$objective
+    if(a$objective<L0){
+      k.values[length(k.values) + 1] <- use.k <- a$minimum
+      L1<- a$objective
+    } else {
+      k.values[length(k.values) + 1] <- use.k <- 0
+      L1<- L0  
+    }
+    
+    if(use.k<=.01){
+      k.List<-j.List<-NULL
+      for(j in 1:length(psi1)){
+        a0<-optimize(search.min, c(0,.5), psi=psi1, psi.old=psi0, X=x.lin, y=y, id.fix.psi=j, tol=tolOp[i])
+        a1<-optimize(search.min, c(.5,1), psi=psi1, psi.old=psi0, X=x.lin, y=y, id.fix.psi=j, tol=tolOp[i])
+        a <-if(a0$objective<=a1$objective) a0 else a1
+        if(a$objective<L1){
+          j.List[[j]]<-setdiff(1:length(psi1),j) #indici di psi che devono cambiare..
+          k.List[[j]]<-a$minimum
+        } else {
+          j.List[[j]]<-NA
+          k.List[[j]]<-NA
+          
+        }
+      }
+      id.to.be.changed<- unique(unlist(j.List[!sapply(k.List, is.na)]))
+      if(!is.null(id.to.be.changed)){
+        use.k<-rep(0,length(psi1))
+        use.k[id.to.be.changed] <-mean(unlist(k.List[!sapply(k.List, is.na)]))
+        psi1 <- psi1*use.k + psi0* (1-use.k)
+        use.k<-mean(use.k)
+        L1=search.min(1, psi=psi1, psi.old=psi0, X=x.lin, y=y)
+      } else {
+        psi1<-psi0
+      }
+    } else {
+      psi1 <- psi1*use.k + psi0* (1-use.k)
+    }
+    
+    
+    
     
-    #Aggiorna psi
-    psi1 <- psi1*use.k + psi0* (1-use.k)
     if (!is.null(digits)) psi1 <- round(psi1, digits)
     #PSI1 <- matrix(psi1, n, npsi, byrow = TRUE)
     #XREG1 <- cbind(x.lin, Xtrue>PSI1)
@@ -188,7 +239,7 @@ step.ts.fit<-function(y, x.lin, Xtrue, PSI, opz, return.all.sol=FALSE){
                 sep=""), "\n")
     }
     
-    epsilon <- if(conv.psi) max(abs((psi1 -psi0)/psi0)) else (L0 - L1)/(abs(L0) + 0.1) 
+    epsilon <- (L0 - L1)/(abs(L0) + 0.1) 
     L0<-L1
     
     k.values[length(k.values)+1]<-use.k
@@ -201,9 +252,12 @@ step.ts.fit<-function(y, x.lin, Xtrue, PSI, opz, return.all.sol=FALSE){
     }
     psi0<-psi1
   } #end while_it
+  psi1 <-unlist(tapply(psi1, opz$id.psi.group, sort))
+  PSI<- matrix(psi1, n, npsi, byrow = TRUE)
+  U <- 1*(Xtrue>PSI)
   
   #ATTENZIONE .. Assume che obj sia stato stimato sempre!
   obj<-list(obj=obj, psi=psi1, psi.values=psi.values, rangeZ=rangeZ, SumSquares.no.gap=L1, beta.c=b, 
-              it=i, epsilon=epsilon, id.warn=id.warn) 
+              it=i, epsilon=epsilon, id.warn=id.warn, U=U) 
   return(obj)
 } #end jump.fit
